@@ -4,17 +4,19 @@ use 5.10.1 ;
 use strict;
 use warnings;
 
-=head1 NAME
+=head1 DESCRIPTION
 
-SmotifCS - The great new SmotifCS!
+SMOTIFCS implement a hybrid protein modeling algorithms that relies 
+on a library of protein super-secondary structure motifs (Smotifs) 
+and easily obtainable NMR experimental data.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -64,6 +66,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
+
 You can find documentation for this module with the perldoc command.
 
     perldoc SmotifCS
